<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Tray</source>
        <translation>Zone de notification</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <source>Blinking Envelope</source>
        <translation>Enveloppe clignotante</translation>
    </message>
    <message>
        <source>Static Envelope</source>
        <translation>Enveloppe statique</translation>
    </message>
    <message>
        <source>Animated Envelope</source>
        <translation>Enveloppe d&apos;animation</translation>
    </message>
    <message>
        <source>Startup</source>
        <translation>Lancement</translation>
    </message>
    <message>
        <source>Start minimized</source>
        <translation>Démarrer en mode réduit</translation>
    </message>
    <message>
        <source>Show tooltip over tray icon</source>
        <translation>Afficher les notification au dessus de l&apos;icône de notification</translation>
    </message>
    <message>
        <source>Tray icon indicating new message</source>
        <translation>L’icône de la zone de notification indique les nouveaux messages</translation>
    </message>
</context>
<context>
    <name>DockingMenuHandler</name>
    <message>
        <source>&amp;Restore</source>
        <translation>&amp;Restaurer</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Réduire</translation>
    </message>
    <message>
        <source>Silent mode</source>
        <translation>Mode silencieux</translation>
    </message>
    <message>
        <source>&amp;Exit Kadu</source>
        <translation>&amp;Quitter Kadu</translation>
    </message>
</context>
</TS>